<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CopyWithReference</name>
    <message>
        <location filename="../CopyWithReferenceInit.js" line="+2"/>
        <source>&amp;Copy with Reference</source>
        <translatorcomment>--ignored case--
--file: qcadactions_pl.ts--
Kopiuj z punktem &amp;odniesienia</translatorcomment>
        <translation>Skopiuj z &amp;odniesieniem</translation>
    </message>
</context>
</TS>
